==========
Exceptions
==========
.. currentmodule:: polars.exceptions

.. autosummary::
    :toctree: api/
    :nosignatures:

    ArrowError
    ColumnNotFoundError
    ComputeError
    DuplicateError
    InvalidOperationError
    NoDataError
    NoRowsReturnedError
    PolarsPanicError
    RowsError
    SchemaError
    SchemaFieldNotFoundError
    ShapeError
    StructFieldNotFoundError
    TooManyRowsReturnedError
